@@ -6,6 +6,7 @@
 
 #include "folderplugin.h"
 #include "applauncher.h"
+#include "desktopschemehelper.h"
 #include "directorypicker.h"
 #include "eventgenerator.h"
 #include "foldermodel.h"
@@ -25,6 +26,13 @@
 #include <QQmlContext>
 #include <QQmlEngine>
 
+static QObject *DesktopSchemeHelperSingletonProvider(QQmlEngine *engine, QJSEngine *jsEngine)
+{
+    Q_UNUSED(engine);
+    Q_UNUSED(jsEngine);
+    return new DesktopSchemeHelper();
+}
+
 static QObject *menuHelperSingletonProvider(QQmlEngine *engine, QJSEngine *jsEngine)
 {
     Q_UNUSED(engine);
@@ -42,6 +50,7 @@ static QObject *appLauncherSingletonProvider(QQmlEngine *engine, QJSEngine *jsEn
 void FolderPlugin::registerTypes(const char *uri)
 {
     Q_ASSERT(QLatin1String(uri) == QLatin1String("org.kde.private.desktopcontainment.folder"));
+    qmlRegisterSingletonType<DesktopSchemeHelper>(uri, 0, 1, "DesktopSchemeHelper", DesktopSchemeHelperSingletonProvider);
     qmlRegisterType<DirectoryPicker>(uri, 0, 1, "DirectoryPicker");
     qmlRegisterType<FolderModel>(uri, 0, 1, "FolderModel");
     qmlRegisterType<ItemViewAdapter>(uri, 0, 1, "ItemViewAdapter");
