@@ -7,8 +7,6 @@
 
 #include "previewpluginsmodel.h"
 
-#include <KServiceTypeTrader>
-
 #include <KIO/PreviewJob>
 
 #include <algorithm>
@@ -24,7 +22,7 @@ PreviewPluginsModel::PreviewPluginsModel(QObject *parent)
 {
     std::stable_sort(m_plugins.begin(), m_plugins.end(), lessThan);
 
-    m_checkedRows = QVector<bool>(m_plugins.size(), false);
+    m_checkedRows = QList<bool>(m_plugins.size(), false);
 }
 
 PreviewPluginsModel::~PreviewPluginsModel()
@@ -88,9 +86,9 @@ void PreviewPluginsModel::setCheckedPlugins(const QStringList &list)
         plugins = KIO::PreviewJob::defaultPlugins();
     }
 
-    m_checkedRows = QVector<bool>(m_plugins.size(), false);
+    m_checkedRows = QList<bool>(m_plugins.size(), false);
 
-    for (const QString &name : qAsConst(plugins)) {
+    for (const QString &name : std::as_const(plugins)) {
         const int row = indexOfPlugin(name);
         if (row != -1) {
             m_checkedRows[row] = true;
