@@ -10,6 +10,7 @@
 #include <KPackage/Package>
 #include <KQuickManagedConfigModule>
 
+#include <QAction>
 #include <QJsonArray>
 #include <QJsonValue>
 #include <QSortFilterProxyModel>
@@ -87,6 +88,8 @@ public:
 
     Q_INVOKABLE void openKCM(const QString &kcm);
 
+    Q_INVOKABLE QAction *kcmAction(const QString &storageId);
+
 public Q_SLOTS:
     void save() override;
 
